@@ -305,7 +305,14 @@ _format_todo_time(CComponent* component, gchar* buf, CalHomePlugin* desktop_plug
   else
   {
     struct tm* time = localtime(&start_time);
-    strftime(buf, 255,dgettext("hildon-libs","wdgt_va_date_short"), time);
+    if(desktop_plugin->show_week_day_name)
+    {
+      strftime(buf, 255, dgettext("hildon-libs","wdgt_va_date_day_name_short"), time);
+    }
+    else
+    {
+      strftime(buf, 255, dgettext("hildon-libs","wdgt_va_date_short"), time);
+    }
   }
 }
 
@@ -365,15 +372,17 @@ cal_condense_ccomponents_set_to_list_store(const SortedCComponentSet& ccomponent
     time_t event_start_time = (*event_iter)->getDateStart();
     time_t event_end_time = (*event_iter)->getDateEnd();
     time_t event_time_offset = (*event_iter)->getTzOffset();
-    struct tm* time = localtime(&event_start_time);
 
-    if(CMulticalendar::MCInstance()->getSystemTimeZone() != (*event_iter)->getTzid() &&
+
+    if(CMulticalendar::MCInstance()->getSystemTimeShift() != (*event_iter)->getTzOffset() &&
        (*event_iter)->getAllDay())
     {
       event_end_time += event_time_offset - system_time_offset;
       event_start_time += event_time_offset - system_time_offset;
     }
 
+    struct tm* time = localtime(&event_start_time);
+
     if(earliest_update_end_time>event_end_time)
       earliest_update_end_time = end_time+60;
     if(date_today_time < event_start_time &&
@@ -790,22 +799,24 @@ cal_read_ccomponents_all_visible(SortedCComponentSet& all_components,
     if(error == 500)
     {
       
-      cal_read_ccomponents_for_calendar(cal,
-					start_time,
-					end_time,
-					all_components, FALSE,
-					desktop_plugin);
-
-      // gnark, birthday events start and end
-      // at 00:00:00
-
-      cal_read_ccomponents_for_calendar(cal,
-					today_midnight_time,
-					end_time,
-					all_components, TRUE,
-					desktop_plugin);
-
-
+      if(desktop_plugin->visible_entry_mode == VISIBLE_ENTRY_EVENT ||
+	 desktop_plugin->visible_entry_mode == VISIBLE_ENTRY_EVENT_AND_TASK)
+      {
+	cal_read_ccomponents_for_calendar(cal,
+					  start_time,
+					  end_time,
+					  all_components, FALSE,
+					  desktop_plugin);
+	
+	// gnark, birthday events start and end
+	// at 00:00:00
+	
+	cal_read_ccomponents_for_calendar(cal,
+					  today_midnight_time,
+					  end_time,
+					  all_components, TRUE,
+					  desktop_plugin);
+      }
       if(desktop_plugin->visible_entry_mode == VISIBLE_ENTRY_TASK ||
 	 desktop_plugin->visible_entry_mode == VISIBLE_ENTRY_EVENT_AND_TASK)
       {
