@@ -27,6 +27,8 @@
 #define CAL_HP_KEY_CAL_SHOW_AGE "cal_show_age"
 #define CAL_HP_KEY_CAL_UPDATE_IF_VISIBLE "update_if_visible"
 #define CAL_HP_KEY_CAL_SHOW_ALL_RECURRENCES "show_all_recurrences"
+#define CAL_HP_KEY_CAL_SHOW_OLD_UNDONE_TASKS "show_old_undone_tasks"
+#define CAL_HP_KEY_CAL_SHOW_DONE_TASKS "show_done_tasks"
 #define CAL_HP_KEY_CAL_SHOW_WEEK_DAY_NAME "show_week_day_name"
 #define CAL_HP_KEY_CAL_VISIBLE_ENTRY_MODE "visible_entry_mode"
 #define CAL_HOME_PLUGIN_SETTINGS_FILE "/.cal_home_widget"
@@ -93,6 +95,20 @@ cal_home_read_settings(CalHomePlugin *desktop_plugin)
 								    CAL_HP_KEY_CAL_SHOW_ALL_RECURRENCES,
 								    NULL);
     }
+    if(g_key_file_has_key(keyFile, desktop_plugin->iD, CAL_HP_KEY_CAL_SHOW_OLD_UNDONE_TASKS, NULL))
+    {
+      desktop_plugin->show_old_undone_tasks = g_key_file_get_boolean(keyFile, 
+								     desktop_plugin->iD, 
+								     CAL_HP_KEY_CAL_SHOW_OLD_UNDONE_TASKS,
+								     NULL);
+    }
+    if(g_key_file_has_key(keyFile, desktop_plugin->iD, CAL_HP_KEY_CAL_SHOW_DONE_TASKS, NULL))
+    {
+      desktop_plugin->show_done_tasks = g_key_file_get_boolean(keyFile, 
+							       desktop_plugin->iD, 
+							       CAL_HP_KEY_CAL_SHOW_DONE_TASKS,
+							       NULL);
+    }
     if(g_key_file_has_key(keyFile, desktop_plugin->iD, CAL_HP_KEY_CAL_SHOW_WEEK_DAY_NAME, NULL))
     {
       desktop_plugin->show_week_day_name = g_key_file_get_boolean(keyFile, 
@@ -135,6 +151,8 @@ cal_home_save_settings(CalHomePlugin* desktop_plugin)
   g_key_file_set_boolean (keyFile, desktop_plugin->iD, CAL_HP_KEY_CAL_SHOW_AGE, desktop_plugin->show_age);
   g_key_file_set_boolean (keyFile, desktop_plugin->iD, CAL_HP_KEY_CAL_UPDATE_IF_VISIBLE, desktop_plugin->update_if_visible);
   g_key_file_set_boolean (keyFile, desktop_plugin->iD, CAL_HP_KEY_CAL_SHOW_ALL_RECURRENCES, desktop_plugin->show_all_recurrences);
+  g_key_file_set_boolean (keyFile, desktop_plugin->iD, CAL_HP_KEY_CAL_SHOW_OLD_UNDONE_TASKS, desktop_plugin->show_old_undone_tasks);
+  g_key_file_set_boolean (keyFile, desktop_plugin->iD, CAL_HP_KEY_CAL_SHOW_DONE_TASKS, desktop_plugin->show_done_tasks);
 
   g_key_file_set_boolean (keyFile, desktop_plugin->iD, CAL_HP_KEY_CAL_SHOW_WEEK_DAY_NAME, desktop_plugin->show_week_day_name);
   g_key_file_set_integer (keyFile, desktop_plugin->iD, CAL_HP_KEY_CAL_VISIBLE_ENTRY_MODE, desktop_plugin->visible_entry_mode);
